#[non_exhaustive]pub enum KeyParsingError {
FailedToDecodeHex {
meta: Meta,
},
FailedToDecodeBase32 {
meta: Meta,
},
InvalidLength {
meta: Meta,
},
InvalidKeyData {
meta: Meta,
},
}Available on crate feature
key only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FailedToDecodeHex
The input string could not be decoded as hex.
FailedToDecodeBase32
The input string could not be decoded as base32.
InvalidLength
The input has invalid length.
InvalidKeyData
The decoded data is not a valid Ed25591 public key.