CustomAddr

Struct CustomAddr 

pub struct CustomAddr { /* private fields */ }
Available on crate feature key only.
A custom address.

This is a generic address type with a type id and opaque data, to allow external crates to implement custom transports.

Custom addresses can be written by anybody, so you need to be prepared to handle unexpected type ids and data when parsing custom addresses.

Implementations

Source

impl CustomAddr

pub fn from_parts(id: u64, data: &[u8]) -> Self

Creates a new CustomAddr from its parts.

pub fn id(&self) -> u64

Returns the transport id.

You can freely choose this. There is a table of reserved custom transport ids in https://github.com/n0-computer/iroh/blob/main/TRANSPORTS.md, where you could submit your transport for registration to get a reserved id.

But this is only relevant if you care for interop.

pub fn data(&self) -> &[u8]

Returns the opaque address data for this transport.

Below a certain size (currently 30 bytes) this is stored inline, otherwise on the heap.

Note that there are no guarantees about the size of this data. When parsing custom addresses you must be prepared to handle unexpected sizes here.

pub fn as_vec(&self) -> Vec<u8>

Convert to byte representation

pub fn from_bytes(data: &[u8]) -> Result<Self, &'static str>

Parse from bytes